.. _api-commands:

Package plumbum.commands
========================
.. automodule:: plumbum.commands.base
   :members:
   :special-members:

.. automodule:: plumbum.commands.daemons
   :members:
   :special-members:

.. automodule:: plumbum.commands.modifiers
   :members:
   :special-members:

.. automodule:: plumbum.commands.processes
   :members:
   :special-members:
